@@ -55,7 +55,7 @@ QWidget *AttendeeComboBoxDelegate::createEditor(QWidget *parent, const QStyleOpt
 {
     auto editor = new AttendeeComboBox(parent);
 
-    for (const QPair<QIcon, QString> &pair : qAsConst(mEntries)) {
+    for (const QPair<QIcon, QString> &pair : std::as_const(mEntries)) {
         editor->addItem(pair.first, pair.second);
     }
 
@@ -159,3 +159,5 @@ bool AttendeeComboBoxDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *v
     }
     return QStyledItemDelegate::helpEvent(event, view, option, index);
 }
+
+#include "moc_attendeecomboboxdelegate.cpp"
